<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.webtoffee.com
 * @since             1.0.0
 * @package           Wt_Social_Login
 *
 * @wordpress-plugin
 * Plugin Name:      Social Login for WordPress
 * Plugin URI:
 * Description:       Social login is a form of single sign-on using existing information from a social networking service such as Facebook,  or Google, to sign into a third party website instead of creating a new login account specifically for the website. It is designed to simplify logins for end users as well as provide more and more reliable demographic information to web developers
 * Version:           0.0.2
 * Author:            markhf
 * Author URI:
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wt-social-login
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}


// include( 'admin/class-wishlist_webtoffee_settings.php' );
define('WT_SOCIAL_LOGIN_BASEPATH', plugin_dir_path(__FILE__));
define('WT_SOCIAL_LOGIN_BASEURL', plugin_dir_url(__FILE__));



/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'WT_SOCIAL_LOGIN_VERSION', '0.0.2' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-wt-social-login-activator.php
 */
function activate_wt_social_login() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wt-social-login-activator.php';
	Wt_Social_Login_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-wt-social-login-deactivator.php
 */
function deactivate_wt_social_login() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wt-social-login-deactivator.php';
	Wt_Social_Login_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_wt_social_login' );
register_deactivation_hook( __FILE__, 'deactivate_wt_social_login' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-wt-social-login.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_wt_social_login() {

	$plugin = new Wt_Social_Login();
	$plugin->run();
}

//todo Move to inner Page
function wt_sl_support_link( $links ) {
    $links = array_merge( array(
        '<a  target="_blank" href="https://wordpress.org/support/plugin/wt-social-login">' . __( 'Support', 'wt-social-login' ) . '</a>'
    ), $links );
    return $links;
}
add_action( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'wt_sl_support_link' );

function wt_sl_settings_link( $links ) {
    $links = array_merge( array(
        '<a href="' . esc_url( admin_url( '/admin.php?page=wt-social-login' ) ) . '">' . __( 'Settings', 'wt-social-login' ) . '</a>'
    ), $links );
    return $links;
}
add_action( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'wt_sl_settings_link' );

run_wt_social_login();



